( cd usr/lib ; rm -rf libbakery-2.3-2.3.so.15 )
( cd usr/lib ; ln -sf libbakery-2.3-2.3.so.15.0.0 libbakery-2.3-2.3.so.15 )
( cd usr/lib ; rm -rf libbakery-2.3.so )
( cd usr/lib ; ln -sf libbakery-2.3-2.3.so.15.0.0 libbakery-2.3.so )
